@@ -28,7 +28,8 @@
 #include <libgnomecanvas/gnome-canvas.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtkliststore.h>
-
+#include <gtk/gtktreeviewcolumn.h>
+#include <libgnomevfs/gnome-vfs-async-ops.h>
 #include <sys/types.h>
 
 typedef enum {
@@ -37,25 +38,20 @@ typedef enum {
 	CRASH_NONE
 } CrashType;
 
+/* keep in sync with mail config page */
 typedef enum {
-	SUBMIT_REPORT,
-	SUBMIT_TO_SELF,
+	SUBMIT_GNOME_MAILER,
+	SUBMIT_SENDMAIL,
 	SUBMIT_FILE
 } SubmitType;
 
 typedef enum {
-	BUG_NEW,
-	BUG_EXISTING
-} BugType;
-
-typedef enum {
-	STATE_INTRO,
 	STATE_GDB,
-	STATE_DESC,
-	STATE_UPDATE,
 	STATE_PRODUCT,
 	STATE_COMPONENT,
-	STATE_SYSTEM,
+	STATE_MOSTFREQ,
+	STATE_DESC,
+	STATE_EMAIL_CONFIG,
 	STATE_EMAIL,
 	STATE_FINISHED,
 	STATE_LAST
@@ -85,6 +81,9 @@ extern PoptData popt_data;
 typedef struct {
 	GladeXML  *xml;
 	BuddyState state;
+	gboolean	product_skipped;
+	gboolean	component_skipped;
+	gboolean	mostfreq_skipped;
 
 	/* canvas stuff */
 	GnomeCanvasItem *title_box;
@@ -101,9 +100,6 @@ typedef struct {
 
 	gboolean already_run;
 
-#if 0
-	Distribution      *distro;
-#endif
 	char              *bts_file;
 
 	CrashType  crash_type;
@@ -118,18 +114,17 @@ typedef struct {
 	int         fd;
 	gboolean    explicit_dirty;
 
-	BugzillaBTS *all_products;
-	GSList      *bugzillas;
+	GHashTable  *bugzillas;
+	GSList *applications;
+	GHashTable *program_to_application;
+	char *current_appname;
 
 	/* Debian BTS stuff */
 	SubmitType    submit_type;
-#if 0
-	BugType       bug_type; 
-	SeverityType  severity;
-	BugClassType  bug_class;
-#endif
 	GSList       *packages;
 
+	GSList       *bugs;
+
 	/* Bugzilla BTS stuff */
 	BugzillaProduct   *product;
 	BugzillaComponent *component;
@@ -138,8 +133,23 @@ typedef struct {
 	GList *dlsources;
 	GList *dldests;
 
+	int last_update_check;
+	gboolean download_in_progress;
+
 	GnomeVFSAsyncHandle *vfshandle;
 	gboolean need_to_download;
+
+	GtkTreeViewColumn *uri_column;
+	gboolean           showing_hand;
+
+	const char *gnome_version;
+
+	char *gnome_platform_version;
+	char *gnome_vendor;
+
+	guint dl_timeout;
+
+	gboolean show_products;
 } DruidData;
 
 extern DruidData druid_data;
@@ -162,7 +172,9 @@ void append_packages (void);
 void load_config (void);
 void save_config (void);
 
-#define GET_WIDGET(name) (glade_xml_get_widget (druid_data.xml, (name)))
+#define GET_WIDGET(name) (get_widget ((name), (G_STRLOC)))
+
+GtkWidget *get_widget (const char *s, const char *loc);
 
 /* GTK's text widgets have sucky apis */
 char *buddy_get_text_widget (GtkWidget *w);
@@ -171,4 +183,7 @@ char *buddy_get_text_widget (GtkWidget *w);
 void  buddy_set_text_widget (GtkWidget *w, const char *s);
 #define buddy_set_text(w, s) (buddy_set_text_widget (GET_WIDGET (w), s))
 
+void gconf_buddy_connect_string (const char *key, const char *opt_widget);
+void gconf_buddy_connect_bool   (const char *key, const char *opt_widget);
+
 #endif /* __bug_buddy_h__ */
